@@ -39,94 +39,6 @@ import aws_cdk.aws_iam
 import aws_cdk.core
 
 
-@jsii.interface(
-    jsii_type="@renovosolutions/cdk-library-managed-instance-role.IManagedInstanceRoleProps"
-)
-class IManagedInstanceRoleProps(typing_extensions.Protocol):
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="domainJoinEnabled")
-    def domain_join_enabled(self) -> typing.Optional[builtins.bool]:
-        '''Should the role include directory service access with SSM.'''
-        ...
-
-    @domain_join_enabled.setter
-    def domain_join_enabled(self, value: typing.Optional[builtins.bool]) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="managedPolicies")
-    def managed_policies(
-        self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]]:
-        '''The managed policies to apply to the role in addition to the default policies.'''
-        ...
-
-    @managed_policies.setter
-    def managed_policies(
-        self,
-        value: typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]],
-    ) -> None:
-        ...
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="ssmManagementEnabled")
-    def ssm_management_enabled(self) -> typing.Optional[builtins.bool]:
-        '''Should the role include SSM management.
-
-        By default if domainJoinEnabled is true then this role is always included.
-        '''
-        ...
-
-    @ssm_management_enabled.setter
-    def ssm_management_enabled(self, value: typing.Optional[builtins.bool]) -> None:
-        ...
-
-
-class _IManagedInstanceRolePropsProxy:
-    __jsii_type__: typing.ClassVar[str] = "@renovosolutions/cdk-library-managed-instance-role.IManagedInstanceRoleProps"
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="domainJoinEnabled")
-    def domain_join_enabled(self) -> typing.Optional[builtins.bool]:
-        '''Should the role include directory service access with SSM.'''
-        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "domainJoinEnabled"))
-
-    @domain_join_enabled.setter
-    def domain_join_enabled(self, value: typing.Optional[builtins.bool]) -> None:
-        jsii.set(self, "domainJoinEnabled", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="managedPolicies")
-    def managed_policies(
-        self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]]:
-        '''The managed policies to apply to the role in addition to the default policies.'''
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]], jsii.get(self, "managedPolicies"))
-
-    @managed_policies.setter
-    def managed_policies(
-        self,
-        value: typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]],
-    ) -> None:
-        jsii.set(self, "managedPolicies", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="ssmManagementEnabled")
-    def ssm_management_enabled(self) -> typing.Optional[builtins.bool]:
-        '''Should the role include SSM management.
-
-        By default if domainJoinEnabled is true then this role is always included.
-        '''
-        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "ssmManagementEnabled"))
-
-    @ssm_management_enabled.setter
-    def ssm_management_enabled(self, value: typing.Optional[builtins.bool]) -> None:
-        jsii.set(self, "ssmManagementEnabled", value)
-
-# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
-typing.cast(typing.Any, IManagedInstanceRoleProps).__jsii_proxy_class__ = lambda : _IManagedInstanceRolePropsProxy
-
-
 class ManagedInstanceRole(
     aws_cdk.core.Construct,
     metaclass=jsii.JSIIMeta,
@@ -136,13 +48,24 @@ class ManagedInstanceRole(
         self,
         scope: aws_cdk.core.Construct,
         id: builtins.str,
-        props: IManagedInstanceRoleProps,
+        *,
+        domain_join_enabled: typing.Optional[builtins.bool] = None,
+        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+        ssm_management_enabled: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param props: -
+        :param domain_join_enabled: Should the role include directory service access with SSM.
+        :param managed_policies: The managed policies to apply to the role in addition to the default policies.
+        :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
+        props = ManagedInstanceRoleProps(
+            domain_join_enabled=domain_join_enabled,
+            managed_policies=managed_policies,
+            ssm_management_enabled=ssm_management_enabled,
+        )
+
         jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
@@ -151,9 +74,74 @@ class ManagedInstanceRole(
         return typing.cast(aws_cdk.aws_iam.CfnInstanceProfile, jsii.get(self, "instanceProfile"))
 
 
+@jsii.data_type(
+    jsii_type="@renovosolutions/cdk-library-managed-instance-role.ManagedInstanceRoleProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "domain_join_enabled": "domainJoinEnabled",
+        "managed_policies": "managedPolicies",
+        "ssm_management_enabled": "ssmManagementEnabled",
+    },
+)
+class ManagedInstanceRoleProps:
+    def __init__(
+        self,
+        *,
+        domain_join_enabled: typing.Optional[builtins.bool] = None,
+        managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+        ssm_management_enabled: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''
+        :param domain_join_enabled: Should the role include directory service access with SSM.
+        :param managed_policies: The managed policies to apply to the role in addition to the default policies.
+        :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if domain_join_enabled is not None:
+            self._values["domain_join_enabled"] = domain_join_enabled
+        if managed_policies is not None:
+            self._values["managed_policies"] = managed_policies
+        if ssm_management_enabled is not None:
+            self._values["ssm_management_enabled"] = ssm_management_enabled
+
+    @builtins.property
+    def domain_join_enabled(self) -> typing.Optional[builtins.bool]:
+        '''Should the role include directory service access with SSM.'''
+        result = self._values.get("domain_join_enabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def managed_policies(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]]:
+        '''The managed policies to apply to the role in addition to the default policies.'''
+        result = self._values.get("managed_policies")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.ManagedPolicy]], result)
+
+    @builtins.property
+    def ssm_management_enabled(self) -> typing.Optional[builtins.bool]:
+        '''Should the role include SSM management.
+
+        By default if domainJoinEnabled is true then this role is always included.
+        '''
+        result = self._values.get("ssm_management_enabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ManagedInstanceRoleProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
-    "IManagedInstanceRoleProps",
     "ManagedInstanceRole",
+    "ManagedInstanceRoleProps",
 ]
 
 publication.publish()
